@@ -1,5 +1,8 @@
 """Implement the build command."""
 import sys
+from typing import Any
+from typing import Dict
+from typing import TYPE_CHECKING
 
 import click
 from _pytask.config import hookimpl
@@ -13,13 +16,17 @@ from _pytask.pluginmanager import get_plugin_manager
 from _pytask.session import Session
 
 
+if TYPE_CHECKING:
+    from typing import NoReturn
+
+
 @hookimpl(tryfirst=True)
-def pytask_extend_command_line_interface(cli):
+def pytask_extend_command_line_interface(cli: click.Group) -> None:
     """Extend the command line interface."""
     cli.add_command(build)
 
 
-def main(config_from_cli):
+def main(config_from_cli: Dict[str, Any]) -> Session:
     """Run pytask.
 
     This is the main command to run pytask which usually receives kwargs from the
@@ -100,7 +107,7 @@ def main(config_from_cli):
     default=None,
     help="Print errors with tracebacks as soon as the task fails.",
 )
-def build(**config_from_cli):
+def build(**config_from_cli: Any) -> "NoReturn":
     """Collect and execute tasks and report the results.
 
     This is the default command of pytask which searches given paths or the current
